pub async fn bootstrap() -> Result<i32>Expand description
Entry point to processes managed by hyperactor_mesh. Any process that is part
of a hyperactor_mesh program should call bootstrap, which then configures
the process according to how it is invoked.
If bootstrap returns any error, it is defunct from the point of view of hyperactor_mesh, and the process should likely exit:
ⓘ
let err = hyperactor_mesh::bootstrap().await;
tracing::error("could not bootstrap mesh process: {}", err);
std::process::exit(1);Use bootstrap_or_die to implement this behavior directly.
Else if the bootstrap returns Ok, the process has cleaned up successfully and
should exit the “main” of the program.